pub fn exclude_from_proxy(
service: &ZapService,
regex: String,
) -> Result<Value, ZapApiError>Expand description
Adds a regex of URLs that should be excluded from the local proxies.
pub fn exclude_from_proxy(
service: &ZapService,
regex: String,
) -> Result<Value, ZapApiError>Adds a regex of URLs that should be excluded from the local proxies.